#
# spec file for package mpclient
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2012 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           mpclient
Version:        0.28
Release:        lp150.1.3
License:        GPL-2.0
Summary:        A minimalist command line interface to MPD
Url:            http://www.musicpd.org/
Group:          Productivity/Multimedia/Sound/Utilities
Source:         http://www.musicpd.org/download/mpc/0/mpc-%{version}.tar.xz
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(libmpdclient) >= 2.9
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
A client for MPD, the Music Player Daemon. mpc connects to a MPD
running on a machine via a network. Accepts input on standard input,
so can be easily used in scripts.

%prep
%setup -q -n mpc-%{version}

%build
%configure 
make %{?_smp_mflags}

%install
%makeinstall
install -m 0755 doc/mpd-pls-handler.sh %{buildroot}%{_bindir}/mpd-pls-handler
install -m 0755 doc/mpd-m3u-handler.sh %{buildroot}%{_bindir}/mpd-m3u-handler
install -m 0755 doc/mppledit %{buildroot}%{_bindir}/mppledit

mkdir -p %{buildroot}%{_sysconfdir}/bash_completion.d/
install -m 0644 doc/mpc-completion.bash %{buildroot}%{_sysconfdir}/bash_completion.d/mpc-completion.sh
rm -rf %{buildroot}%{_datadir}/doc

%files
%doc COPYING NEWS README
%{_bindir}/*
%config %{_sysconfdir}/bash_completion.d
%{_mandir}/man1/*

%changelog
* Thu Sep 28 2017 olaf@aepfle.de
- Update to 0.28
  * let "listall" print songs only
  * "searchplay" supports tags
  * add command "pause-if-playing"
  * format: add escape character to escape sequences
  * use environment variable "MPC_FORMAT"
  * require libmpdclient 2.9 or newer
* Thu Aug 27 2015 Mathias.Homann@opensuse.org
- Update to 0.27:
  0.27 (2015/05/30)
  * fix --enable-debug and --enable-werror
  * add unit tests
  * new command: "searchplay" searches and plays songs from the current playlist
  * fix use-after-free bug
  * new command: "searchadd" works like findadd with non-exact matching
  * improved error handling
  * show directories in command "tab"
  * bash completion: escape '&'
  * add %%mtime%% and %%mdate%% to --format
  * recognize command by unambiguous prefix
  * "insert" queues new songs when "random" mode is enabled
  0.26 (2014/06/03)
  * fix segfault when adding absolute paths
  * "playlist" can show stored playlist
  * "search" supports --format
  0.25 (2013/11/09)
  * fix "insert" with directory argument
  * optimize tab completion commands
  * do character set conversion for tab completion commands
  * require libmpdclient 2.3, MPD 0.16
  0.24 (2013/10/29)
  * configure.ac: fix syntax error
  * new command "toggleoutput"
  * use the "volume" command on MPD 0.18
  * fix search/find with "filename" constraint
  * add search/find with "base" constraint
  * don't strip trailing slashes from absolute URLs
* Tue Jun 18 2013 fisiu@opensuse.org
- Update to 0.23:
  * do character set conversions on client-to-client messages
  * allow trailing slashes in paths that can be directories
  * make "mv" a shortcut for "move"
  * new command "cdprev"
  * support absolute paths in "add" and "update"
  * enable/disable: support output names, multiple arguments
    and "only" mode
  * doc: document missing format keywords
* Tue Feb  7 2012 pascal.bleser@opensuse.org
- update to 0.22:
  * implement the client-to-client protocol (MPD 0.17)
  * sticker: fix crash bug
  * print newline after volume level
  * print status after no-op relative volume change
- changes from 0.21:
  * idle: fix assertion failure on unknown idle event
  * new command "insert"
  * show only playlists on command "lsplaylists"
- changes from 0.20:
  * reactivate "search filename"
  * MixRamp support
  * support --format with "ls" and "listall"
  * new command "clearerror"
  * implement "current --wait"
  * command "add": print the failed song
* Thu Jan 14 2010 detlef@links2linux.de
- new upstream version <0.19>
  * require libmpdclient 2.2
  * reactivate "search filename"
  * MixRamp support
  * support --format with "ls" and "listall"
  * new command "clearerror"
  * implement "current --wait"
  * command "add": print the failed song
* Thu Dec 17 2009 detlef@links2linux.de
- rename to mpclient
* Mon Dec  7 2009 detlef@links2linux.de
- new upstream version <0.19>
  * search: fix "mpc search any"
  * idle: flush output after each idleloop iteration
  * added command "sticker" (MPD 0.15)
  * added command "replaygain" (MPD 0.16)
  * implemented position, id for --format
  * fixed bash completion
* Tue Aug 18 2009 detlef@links2linux.de
- new upstream version <0.17>
  * fixed busy loop while waiting for "idle" response
  * added command "idleloop"
* Thu Jul 23 2009 detlef@links2linux.de
- new upstream version <0.16>
  * added command "current"
  * support the new MPD modes "consume" and "single"
  * added command "idle"
* Mon Feb  2 2009 detlef@links2linux.de
- new upstream version <0.15>
  * optimized and simplified the "add" command, don't obtain and print
    song list when adding directories
  * same optimization for the "ls" command, which did some very
    expensive underscore matching logic using "listall"
  * show MPD error message in "status"
  * fixed special character handling in bash completion
  * fixed two crash bugs due to wrong string pool usage
  * don't fall back to ISO-Latin-1 in unknown locale
  * disable character set conversion to/from pipe
  * fix memory leak in songToFormatedString()
  * fix memory leak in charset_set()
  * Sat Dec 20 2008 - Detlef Reichelt <detlef@links2linux.de> <0.14>-<0.pm.1>
- new upstream version <0.14>
  * Support for date, genre, composer, performer, disc, and comment
  * Added "mpc find"
  * Added "mpc list"
* Tue Mar 27 2007 detlef@links2linux.de
- new upstream version
* Thu Sep 28 2006 detlef@links2linux.de
- new upstream version
* Mon Aug 21 2006 detlef@links2linux.de
- install file-handler
* Sun Aug 13 2006 detlef@links2linux.de
- new upstream version
* Tue Mar 23 2004 malakhanov@gmx.de
- modified for SUSE/Packman
* Wed Mar 10 2004 gbpeck@sbcglobal.net
- Update URL
- Rebuild for official release
* Mon Mar  8 2004 gbpeck@sbcglobal.net
- Version 0.10.1
* Wed Mar  3 2004 gbpeck@sbcglobal.net
- Version 0.10.0
* Fri Feb  6 2004 gbpeck@sbcglobal.net
- Rebuild with mach
* Thu Oct 30 2003 gbpeck@sbcglobal.net
- Version 0.9.2
* Tue Oct  7 2003 gbpeck@sbcglobal.net
- Version 0.9.1
* Tue Sep 30 2003 gbpeck@sbcglobal.net
- Version 0.9.0
* Thu Aug 14 2003 gbpeck@sbcglobal.net
- Initial build
